package database;

import java.sql.*;
import entity.User;
import java.util.Properties;
import java.util.logging.Level;
import java.util.logging.Logger;

public class ConnectDB
{
    private Connection myConnect = null;
    private Statement myStmt = null;
    private DatabaseMetaData myMetaData = null;
    private User user = null;
    private Savepoint mySavePoint = null;
    private String metaDate[] = null; // 0 - name driver, 
                                      // 1 - version driver, 
                                      // 2 - database version product, 
                                      // 3 - database product name
    public ConnectDB()
    {
        metaDate = new String[4];
    }
    
    public boolean createConnection(User user)
    {
        this.user = user;
        try
        {
            if(myConnect != null) 
            {
                myConnect.close();
                myConnect = null;
            }
            Class.forName("oracle.jdbc.driver.OracleDriver");
            myConnect = DriverManager.getConnection("jdbc:oracle:thin:@localhost:1521:XE",
                                                    this.user.getLogin(),
                                                    this.user.getPassword());
            if(myConnect == null) 
                return false;
            myConnect.setAutoCommit(false);

            myStmt = myConnect.createStatement();
            
            if(myStmt == null)
                return false;

            myMetaData = myConnect.getMetaData();
            if(myMetaData == null)
                return false;
            metaDate[0] = myMetaData.getDriverName();
            metaDate[1] = myMetaData.getDriverVersion();
            metaDate[2] = myMetaData.getDatabaseProductVersion();
            metaDate[3] = myMetaData.getDatabaseProductName();
            return true;
        }
        catch (Exception e)
        {
            System.err.println("JDBC connecting: ");
            System.err.println(e);
            return false;
        }
    }
    
    public Connection getConnect() {
        return myConnect;
    }

    public Statement getStmt() {
        return myStmt;
    }

    public boolean isConnection()
    {
        try
        {
            return !myConnect.isClosed();
        } catch (Exception e) {return false;}
    }

    public void commit()
    {
        try
        {
            myConnect.commit();
        } catch (Exception e) {}
    }
    
    public void rollback()
    {
        try
        {
            myConnect.rollback();
        } catch (Exception e) {}
    }

    public String[] getMetaDate()
    {
        return metaDate;
    }
    
    public void destroyConnection()
    {
        try
        {
            myConnect.close();
        } catch (Exception e) {}
    }

    public DatabaseMetaData getMyMetaData() {
        return myMetaData;
    }

    public User getUser()
    {
        return user;
    }

    public void rollbackChanges()
    {
//            myConnect.rollback(mySavePoint);
    }
}
