package database;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

import java.util.LinkedList;
import java.util.List;

import entity.Office;

public class OfficeDB 
{
    private Connection myConnect = null;
    private Statement myStmt = null;
    
    public OfficeDB(ConnectDB myConnectDB)
    {
        myConnect = myConnectDB.getConnect();
        myStmt = myConnectDB.getStmt();
    }

    public OfficeDB() {}

    public List loadRecords(String ID_OFFICE) throws SQLException
    {
        List <Office> offices = new LinkedList<Office>();
        if (!myConnect.isClosed()) 
        {
            ResultSet rs;
            if(ID_OFFICE != null)
                rs = myStmt.executeQuery("SELECT * FROM office WHERE id_office = " + ID_OFFICE);
            else
                rs = myStmt.executeQuery("SELECT * FROM office ORDER BY name");
            while (rs.next())
            {
                Office office =
                    new Office(rs.getInt("ID_OFFICE"),
                               rs.getString("NAME"),
                               rs.getString("EMAIL"),
                               rs.getString("PHONE"),
                               rs.getString("COUNTRY"), 
                               rs.getString("CITY"),
                               rs.getString("STREET"), 
                               rs.getInt("CASE"));
                offices.add(office);
            }
        }
        return offices;
    }

    public List searchRecords(String[] arrayOption)
    {
        try
        {
            List<Office> offices = new LinkedList<Office>();
            String query = "";
            if (arrayOption[0] !=  null)
                query += ("name=\'" + arrayOption[0] + "\' AND ");
            if(arrayOption[1] !=  null)
                query += ("country=\'" + arrayOption[1] + "\' AND ");
            if(arrayOption[2] !=  null)
                query += ("city=\'" + arrayOption[2] + "\' AND ");
            query = query.substring(0, (query.length()-5));
            ResultSet rs = myStmt.executeQuery("SELECT * FROM office WHERE " + query + "ORDER BY name");
            while (rs.next())
            {
                Office office =
                    new Office(rs.getInt("ID_OFFICE"),
                               rs.getString("NAME"),
                               rs.getString("EMAIL"),
                               rs.getString("PHONE"),
                               rs.getString("COUNTRY"),
                               rs.getString("CITY"),
                               rs.getString("STREET"), 
                               rs.getInt("CASE"));
                offices.add(office);
            }
            return offices;
        }
        catch (Exception ex) {return null;}
    }

    public void addOffice(String NAME, String EMAIL, String PHONE,
                  String COUNTRY, String CITY, String STREET, int CASE) 
    {
        try
        {
            if (!myConnect.isClosed())
            {
                PreparedStatement prst = myConnect.prepareStatement("INSERT INTO office VALUES (OFFICE_SEQ.NEXTVAL,?1,?2,?3,?4,?5,?6,?7)");
                prst.setString(1, NAME);
                prst.setString(2, EMAIL);
                prst.setString(3, PHONE);
                prst.setString(4, COUNTRY);
                prst.setString(5, CITY);
                prst.setString(6, STREET);
                prst.setInt(7, CASE);
                prst.execute();
                prst.close();
            }
        }
        catch (Exception ex) {return;}
    }
    
    public void updateOffice(int ID_OFFICE, String NAME, String EMAIL, String PHONE,
                  String COUNTRY, String CITY, String STREET, int CASE) throws Exception
    {
        try
        {
            if (!myConnect.isClosed())
            {
                PreparedStatement prst = myConnect.prepareStatement("UPDATE office SET name=?1, email=?2, phone=?3, country=?4, city=?5, street=?6, case=?7 WHERE id_office = ?8");
                prst.setString(1, NAME);
                prst.setString(2, EMAIL);
                prst.setString(3, PHONE);
                prst.setString(4, COUNTRY);
                prst.setString(5, CITY);
                prst.setString(6, STREET);
                prst.setInt(7, CASE);
                prst.setInt(8, ID_OFFICE);
                prst.execute();
                prst.close();
            }
        }
        catch (Exception ex) {return;}
    }

    public void deleteOffice(int ID_OFFICE) throws Exception
    {
        if (!myConnect.isClosed())
        {
            PreparedStatement prst_sale =
                myConnect.prepareStatement("DELETE FROM sale WHERE id_manager IN (SELECT id_manager " +
                                                                                 "FROM manager " +
                                                                                 "WHERE id_office = (SELECT id_office " +
                                                                                                    "FROM office " +
                                                                                                    "WHERE id_office = ?1))");
            PreparedStatement prst_car =
                myConnect.prepareStatement("DELETE FROM car WHERE id_office = ?1");
            PreparedStatement prst_manager =
                myConnect.prepareStatement("DELETE FROM manager WHERE id_office = ?1");
            PreparedStatement prst_office =
                myConnect.prepareStatement("DELETE FROM office WHERE id_office = ?1");
            prst_sale.setInt(1, ID_OFFICE);
            prst_car.setInt(1, ID_OFFICE);
            prst_manager.setInt(1, ID_OFFICE);
            prst_office.setInt(1, ID_OFFICE);
            prst_sale.execute();
            prst_car.execute();
            prst_manager.execute();
            prst_office.execute();
            prst_sale.close();
            prst_car.close();
            prst_manager.close();
            prst_office.close();
        }
    }
}
