package servlet;

import database.*;
import java.io.IOException;
import java.util.logging.*;
import javax.servlet.ServletException;
import javax.servlet.http.*;

/**
 *
 * @author LibexiN
 */

public class ModelServlet extends HttpServlet
{
    private ConnectDB connectDB;
    private ModelDB modelDB;
    private ManufacturerDB manufacturerDB;

    protected void processRequest(HttpServletRequest request, HttpServletResponse response)
    throws Exception
    {
        response.setContentType("text/html;charset=UTF-8");
        request.setCharacterEncoding("UTF-8");
        connectDB = (ConnectDB) this.getServletContext().getAttribute("connect");
        modelDB = (ModelDB) this.getServletContext().getAttribute("model");
        manufacturerDB = (ManufacturerDB) this.getServletContext().getAttribute("manufacturer");

        if(request.getParameter("edit_page") != null)
        {
            if(request.getParameter("add") != null)
            {
                if(request.getParameter("set_add") != null)
                    procAdd(request);
                else
                    request.setAttribute("flagAdd", "...");
            }
            else if(request.getParameter("update") != null)
            {
                if(request.getParameter("set_update") != null)
                    procUpdate(request);
                else
                {
                    String ID_MODEL = request.getParameter("id_model");
                    request.setAttribute("selected_model", modelDB.loadRecords(ID_MODEL,null,null,null));
                    request.setAttribute("flagUpdate", "...");
                }
            }
            else if(request.getParameter("delete") != null)
            {
                if(request.getParameter("delete_yes") != null)
                    procDelete(request);
                else if(request.getParameter("delete_no") == null)
                {
                    String ID_MODEL = request.getParameter("id_model");
                    request.setAttribute("selected_model", modelDB.loadRecords(ID_MODEL,null,null,null));
                    request.setAttribute("flagDelete", "...");
                }
            }
            else if(request.getParameter("commit") != null)
            {
                connectDB.commit();
            }
            request.setAttribute("models", modelDB.loadRecords(null,null,null,null));
            request.setAttribute("manufacturers", manufacturerDB.loadRecords(null,null,null));
            request.setAttribute("edit_page", "..."); // enable edit page
        }
        else if(request.getParameter("search_page") != null)
        {
            if(request.getParameter("set_search") != null)
            {
                // строки - атрибуты, столбцы: условие и значение
                String arrayOption[][] =
                {
                    {null, null},
                    {null, null},
                    {null, null},
                    {null, null},
                    {null, null},
                    {null, null}
                };
                if(request.getParameter("mark_check") != null)
                {
                    arrayOption[0][1] = request.getParameter("mark");
                }
                if(request.getParameter("max_speed_check") != null)
                {
                    arrayOption[1][0] = request.getParameter("max_speed_condition");
                    arrayOption[1][1] = request.getParameter("max_speed");
                }
                if(request.getParameter("power_check") != null)
                {
                    arrayOption[2][0] = request.getParameter("power_condition");
                    arrayOption[2][1] = request.getParameter("power");
                }
                if(request.getParameter("tank_value_check") != null)
                {
                    arrayOption[3][0] = request.getParameter("tank_value_condition");
                    arrayOption[3][1] = request.getParameter("tank");
                }
                if(request.getParameter("gear_box_check") != null)
                {
                    arrayOption[4][1] = request.getParameter("gear_box");
                }
                if(request.getParameter("weight_check") != null)
                {
                    arrayOption[5][0] = request.getParameter("weight_condition");
                    arrayOption[5][1] = request.getParameter("weight");
                }
                request.setAttribute("find_models", modelDB.searchRecords(arrayOption));
            }
            request.setAttribute("search_page", "..."); // enable search page
        }
        this.getServletContext().getRequestDispatcher("/model.jsp").forward(request, response);
    }

    @Override
    protected void doGet(HttpServletRequest request, HttpServletResponse response)
    throws ServletException, IOException {
        try {
            processRequest(request, response);
        } catch (Exception ex) {
            Logger.getLogger(ModelServlet.class.getName()).log(Level.SEVERE, null, ex);
        }
    } 

    @Override
    protected void doPost(HttpServletRequest request, HttpServletResponse response)
    throws ServletException, IOException {
        try {
            processRequest(request, response);
        }catch (Exception ex) {
            Logger.getLogger(ModelServlet.class.getName()).log(Level.SEVERE, null, ex);
        }
    }

    private void procAdd(HttpServletRequest request) throws Exception
    {
        String MARK = request.getParameter("mark");
        String MODEL = request.getParameter("model");
        String MAX_SPEED = request.getParameter("max_speed");
        String POWER = request.getParameter("power");
        String TANK_VALUE = request.getParameter("tank_value");
        String GEAR_BOX = request.getParameter("gear_box");
        String WEIGHT = request.getParameter("weight");
        String ID_MANUFACTURER = request.getParameter("factory");

        if(MARK == null || MODEL == null || MAX_SPEED == null || POWER == null || TANK_VALUE == null || GEAR_BOX == null || WEIGHT == null || ID_MANUFACTURER == null || ID_MANUFACTURER.equals("_blank"))
            return;
        try {
            modelDB.addModel(MARK, MODEL, Integer.parseInt(MAX_SPEED), Integer.parseInt(POWER),
                    Integer.parseInt(TANK_VALUE), GEAR_BOX, Integer.parseInt(WEIGHT),
                    Integer.parseInt(ID_MANUFACTURER));
        }
        catch (Exception ex) {return;}
    }

    private void procUpdate(HttpServletRequest request) throws Exception
    {
        String ID_MODEL = request.getParameter("id_model");
        String MARK = request.getParameter("new_mark");
        String MODEL = request.getParameter("new_model");
        String MAX_SPEED = request.getParameter("new_max_speed");
        String POWER = request.getParameter("new_power");
        String TANK_VALUE = request.getParameter("new_tank_value");
        String GEAR_BOX = request.getParameter("new_gear_box");
        String WEIGHT = request.getParameter("new_weight");
        String ID_MANUFACTURER = request.getParameter("new_factory");

        if(ID_MODEL == null || MARK == null || MODEL == null || MAX_SPEED == null || POWER == null || TANK_VALUE == null || GEAR_BOX == null || WEIGHT == null || ID_MANUFACTURER == null)
            return;
        try
        {
            modelDB.updateModel(Integer.parseInt(ID_MODEL), MARK, MODEL, Integer.parseInt(MAX_SPEED),
                    Integer.parseInt(POWER), Integer.parseInt(TANK_VALUE), GEAR_BOX,
                    Integer.parseInt(WEIGHT), Integer.parseInt(ID_MANUFACTURER));
        }
        catch (Exception ex) {return;}
    }

    public boolean procDelete(HttpServletRequest request) throws Exception
    {
        String ID_MODEL = (String) request.getParameter("id_model");
        if (ID_MODEL == null)
            return false;
        modelDB.deleteModel(Integer.parseInt(ID_MODEL));
        return true;
    }
}
