package servlet;

import database.*;
import java.io.IOException;
import java.sql.SQLException;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.servlet.ServletException;
import javax.servlet.http.*;

/**
 *
 * @author LibexiN
 */

public class OfficeServlet extends HttpServlet
{
    private ConnectDB connectDB;
    private OfficeDB officeDB;
    private ManagerDB managerDB;
    private CarDB carDB;
    private ModelDB modelDB;
    private SaleDB saleDB;
    private ManufacturerDB manufacturerDB;

    protected void processRequest(HttpServletRequest request, HttpServletResponse response) throws Exception
    {
        response.setContentType("text/html;charset=UTF-8");
        request.setCharacterEncoding("UTF-8");
        connectDB = (ConnectDB) this.getServletContext().getAttribute("connect");
        officeDB = (OfficeDB) this.getServletContext().getAttribute("office");
        managerDB = (ManagerDB) this.getServletContext().getAttribute("manager");
        carDB = (CarDB) this.getServletContext().getAttribute("car");
        modelDB = (ModelDB) this.getServletContext().getAttribute("model");
        saleDB = (SaleDB) this.getServletContext().getAttribute("sale");
        manufacturerDB = (ManufacturerDB) this.getServletContext().getAttribute("manufacturer");

        if (request.getParameter("view_page") != null)
        {
            String ID_OFFICE = request.getParameter("id_office");
            request.setAttribute("selected_office", officeDB.loadRecords(ID_OFFICE));
            request.setAttribute("managers_of_office", managerDB.loadRecords(null, ID_OFFICE));
            request.setAttribute("cars_of_office", carDB.loadRecords(null,null, ID_OFFICE,null));
            request.setAttribute("models_of_office", modelDB.loadRecords(null, ID_OFFICE, null,null));
            request.setAttribute("sales_of_office", saleDB.loadRecords(null,ID_OFFICE, null));
            request.setAttribute("manuf_of_office", manufacturerDB.loadRecords(null,null, ID_OFFICE));

            request.setAttribute("offices", officeDB.loadRecords(null));
            request.setAttribute("view_page", "..."); // enable view page
        }
        else if(request.getParameter("edit_page") != null)
        {
            if(request.getParameter("add") != null)
            {
                if(request.getParameter("set_add") != null)
                    procAdd(request);
                else
                    request.setAttribute("flagAdd", "...");
            }
            else if(request.getParameter("update") != null)
            {
                if(request.getParameter("set_update") != null)
                    procUpdate(request);
                else
                {
                    String ID_OFFICE = request.getParameter("id_office");
                    request.setAttribute("selected_office", officeDB.loadRecords(ID_OFFICE));
                    request.setAttribute("flagUpdate", "...");
                }
            }
            else if(request.getParameter("delete") != null)
            {
                if(request.getParameter("delete_yes") != null)
                    procDelete(request);
                else if(request.getParameter("delete_no") == null)
                {
                    String ID_OFFICE = request.getParameter("id_office");
                    request.setAttribute("selected_office", officeDB.loadRecords(ID_OFFICE));
                    request.setAttribute("flagDelete", "...");
                }
            }
            else if(request.getParameter("commit") != null)
            {
                connectDB.commit();
            }
            request.setAttribute("offices", officeDB.loadRecords(null));
            request.setAttribute("edit_page", "..."); // enable edit page
        }
        else if(request.getParameter("search_page") != null)
        {
            if(request.getParameter("set_search") != null)
            {
                // строки - атрибуты, столбцы: условие и значение
                String arrayOption[] = {null,null,null};
                if(request.getParameter("name_check") != null)
                {
                    arrayOption[0] = request.getParameter("name");
                }
                if(request.getParameter("country_check") != null)
                {
                    arrayOption[1] = request.getParameter("country");
                }
                if(request.getParameter("city_check") != null)
                {
                    arrayOption[2] = request.getParameter("city");
                }
                request.setAttribute("find_offices", officeDB.searchRecords(arrayOption));
            }
            request.setAttribute("search_page", "..."); // enable search page
        }
        this.getServletContext().getRequestDispatcher("/office.jsp").forward(request, response);
    }

    @Override
    protected void doGet(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        try {
            processRequest(request, response);
        } catch (Exception ex) {
            Logger.getLogger(OfficeServlet.class.getName()).log(Level.SEVERE, null, ex);
        }
    }

    @Override
    protected void doPost(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        try {
            processRequest(request, response);
        } catch (Exception ex) {
            Logger.getLogger(OfficeServlet.class.getName()).log(Level.SEVERE, null, ex);
        }
    }

    public void fillingTables(HttpServletRequest request) throws SQLException {}

    public void procAdd(HttpServletRequest request) throws Exception
    {
        String NAME = request.getParameter("name");
        String EMAIL = request.getParameter("email");
        String PHONE = request.getParameter("phone");
        String COUNTRY = request.getParameter("country");
        String CITY = request.getParameter("city");
        String STREET = request.getParameter("street");
        String CASE = request.getParameter("case");

        if(NAME == null || EMAIL == null || PHONE == null || COUNTRY == null || CITY == null || STREET == null || CASE == null)
            return;
        try{officeDB.addOffice(NAME, EMAIL, PHONE, COUNTRY, CITY, STREET, Integer.parseInt(CASE));}
        catch(Exception ex){return;}
    }

    public void procUpdate(HttpServletRequest request) throws Exception
    {
        String ID_OFFICE = request.getParameter("id_office");
        String NAME = request.getParameter("new_name");
        String EMAIL = request.getParameter("new_email");
        String PHONE = request.getParameter("new_phone");
        String COUNTRY = request.getParameter("new_country");
        String CITY = request.getParameter("new_city");
        String STREET = request.getParameter("new_street");
        String CASE = request.getParameter("new_case");

        if (ID_OFFICE == null || NAME == null || EMAIL == null || PHONE == null || COUNTRY == null || CITY == null || STREET == null)
            return;
        try{officeDB.updateOffice(Integer.parseInt(ID_OFFICE), NAME, EMAIL, PHONE, COUNTRY, CITY, STREET, Integer.parseInt(CASE));} 
        catch (Exception ex){return;}
    }

    public void procDelete(HttpServletRequest request) throws Exception
    {
        String ID_OFFICE = (String) request.getParameter("id_office");
        if (ID_OFFICE == null)
            return;
        officeDB.deleteOffice(Integer.parseInt(ID_OFFICE));
    }
}